@@ -1,3 +1,4 @@
-"""Auxiliar functions that may be used in most modules"""
+"""Auxiliary functions that may be used in most modules"""
+
 from .permutation_distance import compute_permutation_distance  # noqa: F401
 from .setup_initial_solution import setup_initial_solution  # noqa: F401
